@@ -132,6 +132,9 @@ Connect <- R6::R6Class(
     #' `httr::content(res, as = parser)`.
     #' @param ... Additional arguments passed to the request function
     request = function(method, url, ..., parser = "parsed") {
+      old_opt <- options(scipen = 999)
+      on.exit(options(old_opt), add = TRUE)
+
       httr_verb <- get(method, envir = asNamespace("httr"))
       res <- rlang::exec(
         httr_verb,
@@ -815,7 +818,7 @@ Connect <- R6::R6Class(
     schedules = function(start = Sys.time(), end = Sys.time() + 60 * 60 * 24 * 7, detailed = FALSE) {
       warn_experimental("schedules")
       url <- v1_url("experimental", "schedules")
-      query_params <- rlang::list2(
+      query_params <- list(
         detailed = tolower(detailed),
         start = datetime_to_rfc3339(start),
         end = datetime_to_rfc3339(end)
@@ -824,6 +827,22 @@ Connect <- R6::R6Class(
       return(res[["schedules"]])
     },
 
+    # packages --------------------------------------------------
+
+    #' @description Get packages. This endpoint is paginated.
+    #' @param name The package name to filter by.
+    #' @param page_number Page number.
+    #' @param page_size Page size, default 100000.
+    packages = function(name = NULL, page_number = 1, page_size = 100000) {
+      url <- v1_url("packages")
+      query_params <- list(
+        name = name,
+        page_number = page_number,
+        page_size = page_size
+      )
+      self$GET(url, query = query_params)
+    },
+
     # misc utilities --------------------------------------------
 
     #' @description Get documentation.
